@@ -30,7 +30,7 @@ use base qw[ Class::Accessor::Fast ];
 __PACKAGE__->mk_accessors( qw[ _host _password _port  _version ] );
 
 
-our $VERSION = '0.3.0';
+our $VERSION = '0.3.1';
 
 
 #
@@ -61,8 +61,9 @@ sub spawn {
         args          => [ $args ],
         inline_states => {
             # private events
-            '_start'       => \&_onpriv_start,
-            '_send'        => \&_onpriv_send,
+            '_start'             => \&_onpriv_start,
+            '_send'              => \&_onpriv_send,
+            '_post_array2scalar' => \&_onpriv_post_array2scalar,
             # protected events
             '_mpd_data'    => \&_onprot_mpd_data,
             '_mpd_error'   => \&_onprot_mpd_error,
@@ -72,14 +73,25 @@ sub spawn {
         },
         object_states => [
             $commands   => { # general purpose commands
+                # -- MPD interaction: general commands
+                # -- MPD interaction: handling volume & output
                 'volume'           => '_onpub_volume',
                 'output_enable'    => '_onpub_output_enable',
                 'output_disable'   => '_onpub_output_disable',
-
+                # -- MPD interaction: retrieving info from current state
                 'stats'            => '_onpub_stats',
                 '_stats_postback'  => '_onpriv_stats_postback',
-
+                'status'           => '_onpub_status',
+                '_status_postback' => '_onpriv_status_postback',
+                'current'          => '_onpub_current',
+                # -- MPD interaction: altering settings
+                # -- MPD interaction: controlling playback
+                'play'             => '_onpub_play',
+                'playid'           => '_onpub_playid',
+                'pause'            => '_onpub_pause',
+                'stop'             => '_onpub_stop',
                 'next'             => '_onpub_next',
+                'prev'             => '_onpub_prev',
             },
             $collection => { # collection related commands
                 'coll.all_files'    => '_onpub_all_files',
@@ -211,6 +223,20 @@ sub _onpriv_send {
 }
 
 
+#
+# event: _post_array2scalar( $msg )
+#
+# Transform $msg->data from array ref to a single scalar. Useful only
+# as a postback callback, and if there's only one value in data().
+#
+sub _onpriv_post_array2scalar {
+    my $msg  = $_[ARG0];
+    my $data = $msg->data->[0];
+    $msg->data($data);
+    $_[KERNEL]->yield( '_mpd_data', $msg );
+}
+
+
 1;
 
 __END__
